summaryrefslogtreecommitdiff
path: root/ace/Object_Manager.cpp
diff options
context:
space:
mode:
authorirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-08-22 05:38:30 +0000
committerirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-08-22 05:38:30 +0000
commit5fcc127eeca45fe711b81af8ea3505df0ec7b482 (patch)
tree721050a8504705718f5b6e54764f550d0f5b42cc /ace/Object_Manager.cpp
parent6fd665d56bc3600177dd74a3bb15eaca7ceb6524 (diff)
downloadATCD-5fcc127eeca45fe711b81af8ea3505df0ec7b482.tar.gz
*** empty log message ***
Diffstat (limited to 'ace/Object_Manager.cpp')
-rw-r--r--ace/Object_Manager.cpp7
1 files changed, 6 insertions, 1 deletions
diff --git a/ace/Object_Manager.cpp b/ace/Object_Manager.cpp
index db612ea060f..6c158d3182d 100644
--- a/ace/Object_Manager.cpp
+++ b/ace/Object_Manager.cpp
@@ -649,6 +649,10 @@ ACE_Object_Manager::~ACE_Object_Manager (void)
ACE_Cleanup_Info info;
+ // Close and possibly delete all service instances in the Service
+ // Repository.
+ ACE_Service_Config::fini_svcs ();
+
// Call all registered cleanup hooks, in reverse order of
// registration.
while (registered_objects_ &&
@@ -661,7 +665,8 @@ ACE_Object_Manager::~ACE_Object_Manager (void)
(*info.cleanup_hook_) (info.object_, info.param_);
}
// Close and delete all ACE library services and singletons.
ACE_Service_Config::close ();
// Close the main thread's TSS, including its Log_Msg instance.
@@ -661,7 +665,8 @@ ACE_Object_Manager::~ACE_Object_Manager (void)
(*info.cleanup_hook_) (info.object_, info.param_);
}
- // Close and delete all ACE library services and singletons.
+ // Unlink all services in the Service Repository and close/delete
+ // all ACE library services and singletons.
ACE_Service_Config::close ();
// Close the main thread's TSS, including its Log_Msg instance.